
// ------- ATTRIBUTES (VERTEX BUFFER DATA) -------
attribute vec4		attrVertex;
attribute vec4		attrTex0UV;
attribute vec4		attrColor;

// ------- UNIFORMS (SHADER CONSTS) -------
uniform mat4		hu_mPMVMatrix;
uniform mat4		hu_mPMatrix;
uniform mat4		hu_mMMatrix;
uniform mat4		hu_mVMatrix;
uniform vec3		hu_vCameraPos;

uniform vec4		u_vFloatingHighDistanceFunction;
uniform vec2		u_vMinMaxTop;

// ------- INTERPOLATORS (SHADER OUTPUTS) -------
varying float		v_fTex0U;
varying vec4		v_vColor;

float GetGrowingValue(vec4 fnParams, float x)
{
	//return (x < fnParams.z) ? fnParams.x : min(fnParams.x + fnParams.w*(x - fnParams.z), fnParams.y);
	float y = fnParams.x + fnParams.w*(x - fnParams.z);
	return min(fnParams.y, max(fnParams.x, y));
}

void main(void)
{
	vec4 vWorldPos = hu_mMMatrix*attrVertex;
	vec3 vDiff = vWorldPos.xyz - hu_vCameraPos;
	float fDistToCamera = length(vDiff);
	float fMaxHeight = GetGrowingValue(u_vFloatingHighDistanceFunction, fDistToCamera);

	float fTerrainHeight = attrTex0UV.t;
	float fHeightNoTerrain = vWorldPos.y - fTerrainHeight;
	if (fHeightNoTerrain > fMaxHeight)
	{
		vWorldPos.y -= fHeightNoTerrain - fMaxHeight;
	}

	v_fTex0U = attrTex0UV.s;
	v_vColor = attrColor;

	vec4 pos = hu_mVMatrix*vWorldPos;
	gl_Position = hu_mPMatrix*pos;
}
