
#if defined(CONST_COLOR) && !defined(VERTEX_COLOR)
// when "vertex color" not present there is no need to interpolate "const color", send it to pixel shader instead
#undef CONST_COLOR
#endif

// ------- ATTRIBUTES (VERTEX BUFFER DATA) -------
attribute vec4		attrVertex;

#if defined(TEXTURE0) || defined(UV2ALPHA) || defined(DEPTHPEELING)
attribute vec4		attrTex0UV;
#endif

#ifdef VERTEX_COLOR
attribute vec4		attrColor;
#endif

// ------- UNIFORMS (SHADER CONSTS) -------
uniform mat4		uniPMVMatrix;

#if defined(GEONORMALMAP) || defined(GEONORMALMAP09)
uniform vec4		uniHeightmapGeo;
#endif

#ifdef GEONORMALMAP
uniform mat4		uniLocalToGeoMatrix;
#endif

#ifdef GEONORMALMAP09
uniform mat4		hu_mMMatrix;
#endif

#ifdef TEXTURE0
#ifdef TEXTURE_MATRIX
uniform mat4		uniTextureMatrix;
#endif
#endif

#ifdef CONST_COLOR
uniform	vec4		uniColor;
#endif

#ifdef PRIMITIVE_POINTS
uniform	float		uniPointSize;
#endif

// ------- INTERPOLATORS (SHADER OUTPUTS) -------
#if defined(GEONORMALMAP) || defined(GEONORMALMAP09)
varying vec2		varHeightmapUV;
#endif

#if defined(TEXTURE0) || defined(UV2ALPHA) || defined(DEPTHPEELING)
varying vec2		varTex0UV;
#endif

#ifdef VERTEX_COLOR
varying vec4		varColor;
#endif

const float MATH_PI = 3.141592;
const float RAD2DEG = 57.295779;

vec2 P3dToGeo(vec3 p)
{
	vec2 v;
	
	v.x = MATH_PI*0.5 - atan(p.z, p.x);
	if (v.x > MATH_PI*1.0) v.x -= MATH_PI*2.0;
	
	v.y = MATH_PI*0.5 - atan(length(vec2(p.x, p.z)), p.y);

	v.x *= RAD2DEG*100000.0;
	v.y *= RAD2DEG*100000.0;

	return v;
}

void main(void)
{
	gl_Position = uniPMVMatrix*attrVertex;

#ifdef GEONORMALMAP
	vec3 vGeoVertex = vec3(uniLocalToGeoMatrix*attrVertex);
	varHeightmapUV = vec2(vGeoVertex.x - uniHeightmapGeo.x, vGeoVertex.z + uniHeightmapGeo.y)*uniHeightmapGeo.z;
#endif

#ifdef GEONORMALMAP09
	vec2 vGeoVertex = P3dToGeo(vec3(hu_mMMatrix*attrVertex));
	varHeightmapUV = vec2(vGeoVertex.x - uniHeightmapGeo.x, -vGeoVertex.y + uniHeightmapGeo.y)*uniHeightmapGeo.z;
#endif

#if defined(TEXTURE0) || defined(UV2ALPHA) || defined(DEPTHPEELING)
#ifdef TEXTURE_MATRIX
	vec4 vTransUV = uniTextureMatrix*attrTex0UV;
	varTex0UV = vTransUV.st;
#else
	varTex0UV = attrTex0UV.st;
#endif
#endif

#ifdef VERTEX_COLOR
	vec4 vColor = attrColor;
#endif

#ifdef CONST_COLOR
	vColor *= uniColor;
#endif

#ifdef VERTEX_COLOR
	varColor = vColor;
#endif

#ifdef PRIMITIVE_POINTS
	gl_PointSize = uniPointSize;
#endif
}
