package jp.pioneer.ce.aam2.AAM2Kit.common.aidl;
import jp.pioneer.ce.aam2.AAM2Kit.common.aidl.AAM2LocationIner;
import jp.pioneer.ce.aam2.AAM2Kit.common.aidl.AAM2ParkingInfo;
import jp.pioneer.ce.aam2.AAM2Kit.common.aidl.AAM2DeviceSpecInfoIner;
import android.view.MotionEvent;

/**
 * A callback interface used by ISppControl to send
 * synchronous notifications back to its clients.  Note that this is a
 * one-way interface so the server does not block waiting for the client.
 */
 interface IExtEventControl {
    /**
     * Called when the service has a new value for you.
     * @value current state of BT in SPP Service
     */
    oneway void valueChanged(int value);
    
    /**
     * Called when the service has an MotionEvent for you.
     * @ev MotionEvent to be delivered
     */
    oneway void deliverMotionEvent(in MotionEvent ev, in boolean sync);
     
     /**
     * Called when the service has an MotionEvent for you.
     * @ev MotionEvent to be delivered
     */
    oneway void deliverKeyEvent(in KeyEvent ev, in boolean sync);
     
     /**
     * Called when the service has an TrackBallEvent for you.
     * @ev MotionEvent to be delivered
     */
    oneway void deliverTrackBallEvent(in MotionEvent ev, in boolean sync);
     
     /**
     * Called when the service has a parkingInfo for you.
     * @bBreak whether in Parking break
     */
    oneway void onAAM2ReceiveParkingInfo(in AAM2ParkingInfo parkingInfo);
     
     /**
     * Called when the service has a parkingInfo for you.
     * @parkingState whether in Parking break
     */
    oneway void onAAM2BooleanReceiveParkingInfo(boolean parkingState);
     
     /**
     * Called when the service has a locationInfo for you.
     * @locationInfo data from external device
     */
    oneway void onAAM2ReceiveLocationInfo(in AAM2LocationIner locationInfo);
     
     /**
	 * It would be called when receiving parking info, after its implementation
	 * had been registered by PExtServiceIF::pRegisterAuthenListener(IExtAuthenListener)
	 * @state data from service
	 */
    oneway void onAAM2ReceiveAuthenInfo(int state);
	 
     /**
     * Called when the service has a HDMIInfo for you.
     * @bHDMIState whether HDMI is connected
     */
    oneway void onAAM2BooleanReceiveHDMIInfo(boolean bHDMIState);
     
     /**
     * Called while receive start advanced mode state
     * @info is Exteral Device Spec Info
     */     
    oneway void onAAM2StartAdvancedAppMode(in AAM2DeviceSpecInfoIner info);
          /**
     * Called while receive stop advanced mode state
     */     
    oneway void onAAM2StopAdvancedAppMode();
          /**
     * Called while receive RemoteCtrl state
     * @info data from external device
     * @see #EXT_REMOTE_CTRL_AV_CMD_TOGGLE
	 * @see #EXT_REMOTE_CTRL_AV_CMD_PLAY
	 * @see #EXT_REMOTE_CTRL_AV_CMD_PAUSE
	 * @see #EXT_REMOTE_CTRL_AV_CMD_TRACKUP
	 * @see #EXT_REMOTE_CTRL_AV_CMD_TRACKDOWN
	 * @see #EXT_REMOTE_CTRL_AV_CMD_FF
	 * @see #EXT_REMOTE_CTRL_AV_CMD_RW
     */     
    oneway void onAAM2ReceiveRemoteCtrl(int info);
     
     /**
     * This is a callback,  it will be called while new receive body has come from ExtDevice.
     * @param info data from service
     */
    oneway void onAAM2ReceiveInfo(in byte[] receiveBody);
          /**
     * This is a callback,  when external device is touch screen for HDMI Certified
     */
    oneway void onAAM2TouchCoordinates(in MotionEvent event);
     
    oneway void onAAM2ReceiveAppNameRequest();

    oneway void onAAM2ReceiveTrackInfoSettingRequest(in byte[] requestData);

    oneway void onAAM2ReceiveTrackInfoRequest(byte type, in byte[] requestData);
	 
    oneway void onAAM2StartFocus();
	 
    oneway void onAAM2StopFocus();
	 
	 /**
     * Called when the service has a Voice recognition Info for you.
     * @bVRState whether Voice recognition is Available
     */
    oneway void onAAM2BooleanReceiveVRStateInfo(boolean bVRState);
	 /**
     * Called when the service receive VR Reply.
     * @cmd is what kind Command,START or END.
     * @result is Reply result.
     */
    oneway void onAAM2ReceiveVRReply(int cmd, int result);
	 /**
     * Called when the service receive VR Terminate.
     * 
     */
    oneway void onAAM2ReceiveVRTerminate();
	 
	 /**
     * Called when the service has a DriveStopping for you.
     * @DriveStopping
     */
    oneway void onAAM2ReceiveDriveStopping(boolean bDriveStopping);
	 
	 /**
     * Called when the service has a parkingBrake for you.
     * @bParkingBrake
     */
    oneway void onAAM2ReceiveParkingSwitch(boolean bParkingBrake);
	 
	 /**
     * This is a callback,  it will be called while CanBus Data has come from ExtDevice.
     * @param info data from service
     */
    oneway void onAAM2ReceiveSpecificData(in byte[] receiveBody);
     
    int getSoundCategory();	
}
