

package jp.pioneer.mbg.pioneerkit.common.aidl;
import jp.pioneer.mbg.pioneerkit.common.aidl.IExtEventControl;

/**
 * SppControl of defining an interface for calling on to a remote service
 * (running in another process).
 */
interface ISppControl {
    /**
     * Often you want to allow a service to call back to its clients.
     * This shows how to do so, by registering a callback interface with
     * the service.
     */
    void registerCallback(IExtEventControl cb, in String packageName);
    
    /**
     * Remove a previously registered callback interface.
     */
    void unregisterCallback(IExtEventControl cb, in String packageName);
    
    /**
     * register Messanger.
     */
    void registerMessanger(IBinder messanger, in String packageName);
    
    /**
     * remove Messanger.
     */
    void unregisterMessanger(IBinder messanger);
    
    /**
     * Start a new 3rd application.
     */
    boolean start3rdApl(String packageName, String className);
    
    /**
     * Start to accept bt communication.
     */
    boolean startSppAccept();
    
    /**
     * stop to accept bt communication.
     */
    void stopSppAccept(); 
     
     /**
     * get connected device.
     */
    String getConnectedDevice();
    
    /**
     * get Spp state.
     */
    int getSppState();
    
    /**
     * set Service whether auto to start when device boots.
     */
    void setServiceAutoBoot(boolean bAuto);
    
    /**
     * get Service whether set to start automatically when device boots.
     */
    boolean isServiceAutoBoot();
    
	/**
	 * set Service whether to show notification on status bar
	 */
    void setServiceNotification(int notify);
    
    /**
	 * get Service whether to show notification on status bar
	 */
    int getServiceNotification();
    
    /**
	 * send source change info
	 */
    void sendSourceChange(int source);
    
    /**
	 * send keyboard change info
	 */
    void sendKeyboardChange(int state);
    
    /**
	 * request parking info
	 */
    boolean requestParkingInfo();
    
    /**
	 * request location info
	 */
    void requestLocationInfo();
    
    /**
	 * request HDMI State info
	 */
    boolean requestHDMIInfo();
    
	/**
	 * The certified process
	 */    
    boolean setCertifiedPriority(String aplName, String companyName, String secretKey);
    
    /**
	 * The uncertified process
	 */    
    boolean setUnCertifiedPriority(String aplName, String companyName, String secretKey);
    
    
    /**
	 * Notify external device to back to home screen.
	 */
	void backHomeOnExtDevice();
	
	/**
	 * Notify external device the beginning or end status of guide sound in DDN.
	 */
	void sendGuideSound(boolean shift);
	
	/**
	 * To send request/notification to external device.
	 */
	void sendCustomRequest(in byte[] requestBody);
	/**
	 * To set Record BTLog ON/OFF.
	 */
	void setBTLogSwitch(boolean bshift);
	/* 
	* notify sevice HDMI Certified is ok or not
	*/
	void notifyHDMICertifiedStatus(boolean bStatus);
	/* 
	* set location info is need or not
	*/
	void setLocationNeedStatus(boolean bStatus);
	/* 
	* set touch coordinates callback or not
	*/
	void setTouchcoordinatesCall(boolean bNeed);
	/* 
	* set HDMI Matching Status on startup
	*/
	void setHDMIMatchingStatus(boolean bstatus);
	/* 
	* delete service saved cmk string
	*/
	void delServiceCmkStatus();
	
	/* 
	* register RemoteCtl CallBack
	*/
	void registerRemoteCallBack(IExtEventControl cb, in String packageName);
	void unregisterRemoteCallBack(in String packageName);
	
	/* 
	* log 
	*/
	void debugLog(String type, String Tag, String log);
	
	List<String> getLogBuffer();
	
	/* 
	* hdmi matching cancel
	*/
	void setHdmiMatchingCancel(boolean matchingCancel);
	/* 
	* set not handle key 
	*/
	void setNotHandleKey(boolean notHandleKey);
	/*
	* get AdvancedAppMode State 
	*/
	boolean isAdvancedAppMode();
	boolean isAdvancedAppModeByPackageName(in String packageName);
	
	/*
	* Transfer the result of injection to service 
	*/
	void onInjectPEventEnd(long time, boolean rlt);
	
	void onInjectKEventEnd(long time, boolean rlt);
	
	void sendAppName(String appName);
	
	void sendTrackInfoSetting(in byte[] sendData);
	
	void sendTrackInfo(byte type, in byte[] sendData);
	//0 is stop/pause, 1 is playing
	void setMediaPlayerStatus(in String packageName, int status);
	
	boolean getAvAppControlMode(in String packageName);
	
	/* 
	* register App Focus Change listener
	*/
	void registerAppFocusCallBack(IExtEventControl cb, in String packageName);
	
	void unregisterAppFocusCallBack(in String packageName);

	/*
	* get VR State 
	*/
	boolean isVRStateAvailable();
	/*
	* Start Voice Recognition 
	*/
	boolean startVRRecognition(int cmdRequest);
	/*
	* Send Voice Recognition Terminate Reply 
	*/
	boolean sendVRTerminateReply(int result);
	
	/*
	 * request Drive Stopping info
	 */
    boolean isDriveStopping();
    
    /*
	 * request parkingBrake info
	 */
    boolean isParkingSwitch();

    /*
     * refresh Device info XML file for service
    */
	void refreshServiceDeviceInfoXMLFile();
    /*
	 * request Can Bus Data
    */
    boolean requestSpecificData(boolean isNeed);
    /*
    * Set PioneerKit Version
    */
    boolean setPioneerKitVersion(String pkgName,String sdkVersion);
    
    boolean isGoogleVRXmlSupport();
    
    void SetGoogleVRXmlSupport(boolean GoogleVRXmlSupport);
    
    boolean isGoogleVRTestMode();
    
    void SetGoogleVRTestMode(boolean GoogleVRTestMode);
    
    boolean isFocused(in String packageName);
    
    /*
    * Get Binded Application List
    */
    List<String> getBindedAppList();
    
    /*
    * Get Binded Application SDK Version
    */
    String getBindedAppSDKVersion(String pkgName);
    /*
    * set MetaData Status
    */
    void setMetaDataSurpportSts(String pkgName, boolean isMetaSurpport);
    
}
